==> task-3.31.0.tar.gz: task-3.31.0/docs/i18n/tr-TR/docusaurus-plugin-content-docs/current/donate.md <==
---
slug: /donate/
sidebar_position: 16
---

# Bağış Yapma

If you find this project useful, you can consider donating by using one of the channels listed below.

This is just a way of saying "thank you", it won't give you any benefits like higher priority on issues or something similar.

Companies who donate at least $50/month will be featured as a "Gold Sponsor" in the website homepage and on the GitHub repository README. Make contact with [@andreynering][] with the logo you want to be shown. Suspect businesses (gambling, casinos, etc) won't be allowed, though.

## GitHub Sponsorları

The preferred way to donate to the maintainers is via GitHub Sponsors. Just use the following links to do your donation:

- [@andreynering](https://github.com/sponsors/andreynering)
- [@pd93](https://github.com/sponsors/pd93)

## Open Collective

[OpenCollective](https://opencollective.com/task)'i tercih ediyorsan aşağıdaki bağlantıları kullanarak bağış yapabilirsin:

- [Aylık $2](https://opencollective.com/task/contribute/backer-4034/checkout)
- [Aylık $5](https://opencollective.com/task/contribute/supporter-8404/checkout)
- [Aylık $20](https://opencollective.com/task/contribute/sponsor-4035/checkout)
- [Aylık $50](https://opencollective.com/task/contribute/sponsor-28775/checkout)
- [Özel değer - Tek seferlik bağış yapma desteklenir](https://opencollective.com/task/donate)

## PayPal

[@andreynering][]'e PayPal ile de bağış yapabilirsin:

- [Herhangi bir değer - Tek seferlik bağış](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=GSVDU63RKG45A&currency_code=USD&source=url)

## PIX (Sadece Brazilya)

Ve eğer Brazilyalıysan, [bu QR Kodu](/img/pix.png) kullanarak [@andreynering][]'e PIX ile bağış yapabilirsin.

<!-- prettier-ignore-start -->

<!-- prettier-ignore-end -->
[@andreynering]: https://github.com/andreynering

==> task-3.35.0.tar.gz: task-3.35.0/docs/i18n/tr-TR/docusaurus-plugin-content-docs/current/donate.md <==
---
slug: /donate/
sidebar_position: 16
---

# Bağış Yapma

If you find this project useful, you can consider donating by using one of the channels listed below.

This is just a way of saying "thank you", it won't give you any benefits like higher priority on issues or something similar.

Companies who donate at least $50/month will be featured as a "Gold Sponsor" in the website homepage and on the GitHub repository README. Make contact with [@andreynering][] with the logo you want to be shown. Suspect businesses (gambling, casinos, etc) won't be allowed, though.

## GitHub Sponsorları

The preferred way to donate to the maintainers is via GitHub Sponsors. Just use the following links to do your donation. We suggest a 50/50 split to each maintainer of the total amount you plan to donate to the project.

- [@andreynering](https://github.com/sponsors/andreynering)
- [@pd93](https://github.com/sponsors/pd93)

## Open Collective

[OpenCollective](https://opencollective.com/task)'i tercih ediyorsan aşağıdaki bağlantıları kullanarak bağış yapabilirsin:

- [Aylık $2](https://opencollective.com/task/contribute/backer-4034/checkout)
- [Aylık $5](https://opencollective.com/task/contribute/supporter-8404/checkout)
- [Aylık $20](https://opencollective.com/task/contribute/sponsor-4035/checkout)
- [Aylık $50](https://opencollective.com/task/contribute/sponsor-28775/checkout)
- [Özel değer - Tek seferlik bağış yapma desteklenir](https://opencollective.com/task/donate)

## PayPal

[@andreynering][]'e PayPal ile de bağış yapabilirsin:

- [Herhangi bir değer - Tek seferlik bağış](https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=GSVDU63RKG45A&currency_code=USD&source=url)

## PIX (Sadece Brazilya)

Ve eğer Brazilyalıysan, [bu QR Kodu](/img/pix.png) kullanarak [@andreynering][]'e PIX ile bağış yapabilirsin.

<!-- prettier-ignore-start -->

<!-- prettier-ignore-end -->
[@andreynering]: https://github.com/andreynering
